cran_to_spdx: Mapping between 'License' fields and SPDX

cran_to_spdxR Documentation

Mapping between License fields and SPDX

Description

A dataset containing the mapping between the License strings observed in CRAN packages and their approximate match in the SPDX License List.

Format

A data frame with 86 rows and two variables:

LICENSE

A valid License string on CRAN.

SPDX

A valid SPDX license identifier.

https://spdx.org/licenses/.

See Also

Writing R Extensions, Licensing section.

Examples

data("cran_to_spdx")

head(cran_to_spdx, 20)

cffr documentation built on Aug. 24, 2026, 5:11 p.m.