deprecated_cff_to_bib: Previous API: create BibTeX entries from multiple sources

cff_extract_to_bibtexR Documentation

Previous API: create BibTeX entries from multiple sources

Description

[Deprecated] Use as_bibentry() instead.

Usage

cff_extract_to_bibtex(x, what = c("preferred", "references", "all"))

cff_to_bibtex(x, what = c("preferred", "references", "all"))

Arguments

x

The source used to generate the bibentry object with cffr. It can be:

  • A missing value, which retrieves the DESCRIPTION file from your in-development package.

  • An existing cff object created with cff(), cff_create() or as_cff().

  • A path to a CITATION.cff file ("CITATION.cff").

  • The name of an installed package ("jsonlite").

  • A path to a DESCRIPTION file ("DESCRIPTION").

what

Fields to extract from a full cff object. It can be:

  • preferred: Create a single entry with the main citation information of the package (key preferred-citation).

  • references: Extract all entries of the references key.

  • all: Extract both the preferred-citation and references keys.

See vignette("r-cff", package = "cffr").

Value

See as_bibentry().

See Also

Deprecated functions: cff_from_bibtex(), cff_parse_citation(), cff_parse_person(), write_bib()

Examples


# From a `cff` object.
cff_object <- cff()

cff_object

# A `bibentry` object.
bib <- as_bibentry(cff_object)


cffr documentation built on Aug. 24, 2026, 5:11 p.m.