powered by
Use as_bibentry() instead.
as_bibentry()
cff_extract_to_bibtex(x, what = c("preferred", "references", "all"))cff_to_bibtex(x, what = c("preferred", "references", "all"))
cff_to_bibtex(x, what = c("preferred", "references", "all"))
See as_bibentry().
The source used to generate the bibentry object with cffr. It can be:
bibentry
A missing value, which retrieves the DESCRIPTION file from your in-development package.
DESCRIPTION
An existing cff object created with cff(), cff_create() or as_cff().
cff
cff()
cff_create()
as_cff()
A path to a CITATION.cff file ("CITATION.cff").
CITATION.cff
"CITATION.cff"
The name of an installed package ("jsonlite").
"jsonlite"
A path to a DESCRIPTION file ("DESCRIPTION").
"DESCRIPTION"
Fields to extract from a full cff object. It can be:
preferred: Create a single entry with the main citation information of the package (key preferred-citation).
preferred
preferred-citation
references: Extract all entries of the references key.
references
all: Extract both the preferred-citation and references keys.
all
See vignette("r-cff", package = "cffr").
vignette("r-cff", package = "cffr")
Deprecated functions: cff_from_bibtex(), cff_parse_citation(), cff_parse_person(), write_bib()
cff_from_bibtex()
cff_parse_citation()
cff_parse_person()
write_bib()
# \donttest{ # From a `cff` object. cff_object <- cff() cff_object # A `bibentry` object. bib <- as_bibentry(cff_object) # }
Run the code above in your browser using DataLab