| cff_modify | R Documentation |
cff objectAdd new keys to a cff object or modify existing ones.
cff_modify(x, ...)
x |
A |
... |
Named arguments used to modify |
Keys provided in ... override the corresponding key in x.
You can add additional keys not detected by cff_create() using
the keys argument. A list of valid keys can be retrieved with
cff_schema_keys(). See the following guide for additional details:
Citation File Format schema guide.
A cff object.
This function is a wrapper of utils::modifyList().
Core cffr workflow:
cff(),
cff_create(),
cff_validate(),
cff_write()
x <- cff()
x
cff_validate(x)
x_mod <- cff_modify(x,
contact = as_cff_person("A contact"),
message = "This overwrites keys",
title = "New Title",
abstract = "New abstract",
doi = "10.21105/joss.03900"
)
x_mod
cff_validate(x_mod)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.