| cff_schema | R Documentation |
Helper functions with valid values for different keys and definition fields. See the following guide: Citation File Format schema guide.
cff_schema_keys() provides the valid high-level keys of the Citation
File Format.
cff_schema_keys_license() provides valid
SPDX license identifier(s) for the
CITATION.cff file.
cff_schema_definitions_person() and cff_schema_definitions_entity()
return the valid fields to include when defining a
person or entity.
cff_schema_definitions_refs() provides the valid
keys to use in the preferred-citation and references keys.
cff_schema_keys(sorted = FALSE)
cff_schema_keys_license()
cff_schema_definitions_person()
cff_schema_definitions_entity()
cff_schema_definitions_refs()
sorted |
A logical value. If |
A character vector with the names of valid keys for Citation File Format version 1.2.0.
Citation File Format schema guide.
cff_schema_keys(sorted = TRUE)
# Valid license keys.
head(cff_schema_keys_license(), 20)
cff_schema_definitions_person()
cff_schema_definitions_entity()
cff_schema_definitions_refs()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.