cffr: Generate Citation File Format ('CFF') Metadata for R Packages
Source:R/cffr-package.R
cffr-package.RdCitation File Format ('CFF') version 1.2.0 doi:10.5281/zenodo.5171937 is a human- and machine-readable file format that provides citation metadata for software. This package provides core utilities to generate and validate this metadata.
Author
Maintainer: Diego Hernangómez diego.hernangomezherrero@gmail.com (ORCID) [copyright holder]
Authors:
Diego Hernangómez diego.hernangomezherrero@gmail.com (ORCID) [copyright holder]
Other contributors: