Citation File Format ('CFF') version 1.2.0 tools:::Rd_expr_doi("10.5281/zenodo.5171937") is a human- and machine-readable file format for software citation metadata. Core utilities generate, read, write and validate Citation File Format metadata for 'R' packages.
Maintainer: Diego Hernangómez [email protected] (ORCID) [copyright holder]
Authors:
Diego Hernangómez [email protected] (ORCID) [copyright holder]
Other contributors:
Hernangómez D (2021). "cffr: Generate Citation File Format Metadata for R Packages." Journal of Open Source Software, 6(67), 3900. tools:::Rd_expr_doi("10.21105/joss.03900"). https://joss.theoj.org/papers/10.21105/joss.03900.
Druskat S, Spaaks JH, Chue Hong N, Haines R, Baker J, Bliven S, Willighagen E, Pérez-Suárez D, Konovalov A (2021). "Citation File Format." tools:::Rd_expr_doi("10.5281/zenodo.5171937"). https://github.com/citation-file-format/citation-file-format.
Useful links: