Learn R Programming

cffr (version 1.4.2)

cran_to_spdx: Mapping between License fields and SPDX

Description

A dataset containing the mapping between the License strings observed in CRAN packages and their approximate match in the SPDX License List.

Arguments

Format

A data frame with 86 rows and two variables:

LICENSE

A valid License string on CRAN.

SPDX

A valid SPDX license identifier.

See Also

Writing R Extensions, Licensing section.

Examples

Run this code
data("cran_to_spdx")

head(cran_to_spdx, 20)

Run the code above in your browser using DataLab