powered by
License
A dataset containing the mapping between the License strings observed in CRAN packages and their approximate match in the SPDX License List.
A data frame with 86 rows and two variables:
LICENSE
A valid License string on CRAN.
SPDX
A valid SPDX license identifier.
Writing R Extensions, Licensing section.
data("cran_to_spdx") head(cran_to_spdx, 20)
Run the code above in your browser using DataLab