Previous API: Create BibTeX entries from several sources
Source:R/deprecated.R
deprecated_cff_to_bib.Rd Please use
as_bibentry() instead.
Arguments
- x
The source used to generate the
bibentryobject via cffr. It can be:A missing value, which retrieves the
DESCRIPTIONfile from your in-development package.An existing
cffobject created withcff(),cff_create(), oras_cff().Path to a
CITATION.cfffile ("CITATION.cff").The name of an installed package (
"jsonlite").Path to a
DESCRIPTIONfile ("DESCRIPTION").
- what
Fields to extract from a full
cffobject. The value could be:preferred: Create a single entry with the main citation information of the package (keypreferred-citation).references: Extract all entries of thereferenceskey.all: Extract both thepreferred-citationandreferenceskeys.
Value
See as_bibentry().
See also
Deprecated functions:
cff_from_bibtex(),
cff_parse_citation(),
cff_parse_person(),
write_bib()
Examples
# \donttest{
# From a cff object.
cff_object <- cff()
cff_object
#> cff-version: 1.2.0
#> message: If you use this software, please cite it using these metadata.
#> title: My Research Software
#> authors:
#> - family-names: Doe
#> given-names: John
# A bibentry object.
bib <- as_bibentry(cff_object)
# }